@@ -167,11 +167,6 @@ def get_bucketed_trades(
             Q, firstReqDate, lastReqDate = request_write_nlog(
                 Q, sess, auth, url, fd, step=i, startTime=lastReqDate, pause=pause
             )
-            # print(
-            #     f"Req {i}: {firstReqDate.strftime(STRF)}"
-            #     f" --> {lastReqDate.strftime(STRF)}",
-            #     end="\r",
-            # )
             i += 1
 
     # last log before exit
@@ -233,7 +228,7 @@ def reached(lastReqDate, endTime=None):
     endTz = OS_TZ if endTime is None or endTime.tz is None else endTime.tz
     lastTz = OS_TZ if lastReqDate.tz is None else lastReqDate.tz
 
-    return endTime is None or Timestamp(endTime).tz_localize(endTz) <= Timestamp(
+    return endTime is None or Timestamp(endTime).tz_convert(endTz) <= Timestamp(
         lastReqDate
     ).tz_convert(lastTz)
 
@@ -303,7 +298,7 @@ def main_prg():
     )
 
     # making_sure the format is also valid for windows
-    endTime = endTime.tz_localize(OS_TZ).strftime(STRF)
+    endTime = endTime.tz_localize(OS_TZ)  # .strftime(STRF)
 
     query = {
         "binSize": args.binSize,
